@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.6 (default, Jan  8 2020, 19:59:22)  [GCC 7.3.0]
+# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1131,7 +1131,8 @@ class markupType(GeneratedsSuper):
         if (
             self.embedded or
             self.nested or
-            (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
+            (1 if type(self.valueOf_) in [int,float] else self.valueOf_) or
+            self.content_
         ):
             return True
         else:
